<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@link		http://www.gekkoware.org
	*/

	define ("IN-GEKKO", true);

	require_once "../../conf.php";

	LoadLib (
		"file.lib.php", "files"
	);

	require_once GEKKO_SOURCE_DIR."lib/auth.inc.php";

	varImport("action|", "id", "return");

	if (is_admin()) {
		switch ($action) {
			case "delete":
				varImport("path");

				varRequire("path");

				if (!preg_match("/\.\.\//", $path)) {

					// switching to absolute path
					$path = GEKKO_FILE_ROOT.$path;

					if (file_exists($path) && is_writable($path)) {
						if (is_dir($path)) {
							// recursive file deletion
							$files = listdir($path, true);
							while ($file = array_shift($files)) {
								$file = $path."/".$file;
								if (is_dir($file)) {
									@rmdir($file);
								} else {
									@unlink($file);
								}
							}
							@rmdir($path);
						} else {
							// single file deletion
							@unlink($path);
						}
					} else {
						abort(_l("E_NOT_WRITABLE"));
					}

					slog("files: deleted '$path'", "actions", 1);
				} else {
					abort(accessDenied());
				}
			break;
			case "edit":

				varImport("path", "name", "parent", "perm");

				varRequire("path", "name", "parent", "perm");

				if (!preg_match("/\.\.\//", $path)) {

					$rel_path = $path;

					// absolute path
					$path = GEKKO_FILE_ROOT.$path;

					// permissions
					// converting to a binary string before conversion
					$ugo = Array("U", "G", "O");
					$rwx = Array("R", "W", "X");

					$bin = "";
					foreach ($ugo as $col) {
						foreach ($rwx as $row) {
							$bin .= intval(isset($_POST["perm"][$col.$row]));
						}
					}

					// binary to octal
					$oct = base_convert($bin, 2, 8);

					// finally chmod()'ing with octal argument
					chmod($path, intval($oct, 8));

					// filename change (couldn't change data/files)
					if (basename($path) != $name && !preg_match("/..\//", $name)) {
						// renaming file
						rename($path, $path = dirname($path)."/$name");
						$return = urlEvalPrototype("index.php/module=admin/base=files?path=".urlencode(dirname($rel_path)), true, false);
					}

					slog("files: changed properties of '$name'", "actions", 1);

				} else {
					abort(accessDenied());
				}
			break;
			case "upload":

				varImport("path", "mkdir", "new", "download");

				varRequire("path");

				if (!preg_match("/\.\.\//", $path)) {

					$abs_path = GEKKO_FILE_ROOT.$path;

					if (!is_writable($abs_path))
						abort(_l("E_NOT_WRITABLE"));

					// creating directories
					foreach ($mkdir as $new_dir) {
						if (!trim($new_dir))
							continue;
						$new_dir = $abs_path.$new_dir;
						@mkdir($new_dir, 0775);
						@chmod($new_dir, 0775);
					}

					// creating empty files
					foreach ($new as $new_file) {
						if (!trim($new_file))
							continue;
						$new_file = $abs_path.$new_file;
						touch($new_file);
						chmod($new_file, 0775);
					}

					// getting files from user upload
					foreach ($_FILES["file"]["tmp_name"] as $id => $tmp) {
						if ($_FILES["file"]["name"][$id]) {
							if ($_FILES["file"]["error"][$id]) {
								trigger_error(uploadError($_FILES["file"]["name"][$id]), E_USER_ERROR);
							}
							if (trim($tmp)) {
								saveFile (
									$tmp,
									"data/files/$path",
									$_FILES["file"]["name"][$id],
									true
								);
							}
						}
					}

					// downloading files from a given url
					foreach ($download as $url) {
						if (trim($url)) {
							saveFile (
								$url,
								"data/files/$path",
								basename(urldecode($url))
							);
						}
					}

					slog("file: file was uploaded/downloaded", "actions", 1);
				} else {
					abort(accessDenied());
				}
			break;
			default:
				abort(_l("L_UNDEFINED_ACTION"));
			break;
		}
	}

	redirect($return);

	db_exit();
?>