<?php

	/*
	*	Gekko - Open Source Web Development Framework
	*	------------------------------------------------------------------------
	*	Copyright (C) 2004-2006, J. Carlos Nieto <xiam@users.sourceforge.net>
	*	This program is Free Software.
	*
	*	@package	Gekko
	*	@license	http://www.gnu.org/copyleft/gpl.html GNU/GPL License 2.0
	*	@author		J. Carlos Nieto <xiam@users.sourceforge.net>
	*	@link		http://www.gekkoware.org
	*/

	if (!defined("IN-GEKKO")) die("Get a life!");

	define("GEKKO_FILE_ROOT", GEKKO_USER_DIR."data/files/");

	mkworkdir(GEKKO_FILE_ROOT);

	Class Files {
		function delete($source) {
			if (is_dir($source)) {
				$dir = opendir($source);
				while (($file = readdir($dir)) != false)
					if ($file != "." && $file != "..")
						files::delete("$source/$file");
				closedir($dir);
				rmdir($source);
			} else {
				unlink($source);
			}
		}
		function copy($source, $destination) {
			if (is_dir($source)) {
				if (!file_exists($destination))
					mkdir($destination);
				$dir = opendir($source);
				while (($file = readdir($dir)) != false)
					if ($file != "." && $file != "..")
						files::copy("$source/$file", "$destination/$file");
				closedir($dir);
			} else {
				copy ($source, $destination);
			}
		}
		function createThumbnail($file) {
			if (file_exists($file) && guessFileType($file) == "image") {
				loadLib("image.lib.php");

				// unique id
				$id = thumbName($file);
				$dest = "data/thumbs/$id";

				if (!file_exists($dest)) {
					$thumb = mkthumbnail($file, 150, false, false, $dest, true);
					return $thumb["url"];
				} else {
					return $dest;
				}
			}
			return files::fetchIcon($file, 48);
		}
		/**
		* readablePerms()
		* @returns: file permissions in human readable format
		*/
		function readablePerms($perms) {
			/* Borrowed from php.net */

			if (($perms & 0xC000) == 0xC000) {
				// Socket
				$info = 's';
			} elseif (($perms & 0xA000) == 0xA000) {
				// Symbolic Link
				$info = 'l';
			} elseif (($perms & 0x8000) == 0x8000) {
				// Regular
				$info = '-';
			} elseif (($perms & 0x6000) == 0x6000) {
				// Block special
				$info = 'b';
			} elseif (($perms & 0x4000) == 0x4000) {
				// Directory
				$info = 'd';
			} elseif (($perms & 0x2000) == 0x2000) {
				// Character special
				$info = 'c';
			} elseif (($perms & 0x1000) == 0x1000) {
				// FIFO pipe
				$info = 'p';
			} else {
				// Unknown
				$info = 'u';
			}

			// Owner
			$info .= (($perms & 0x0100) ? 'r' : '-');
			$info .= (($perms & 0x0080) ? 'w' : '-');
			$info .= (($perms & 0x0040) ? (($perms & 0x0800) ? 's' : 'x' ) : (($perms & 0x0800) ? 'S' : '-'));

			// Group
			$info .= (($perms & 0x0020) ? 'r' : '-');
			$info .= (($perms & 0x0010) ? 'w' : '-');
			$info .= (($perms & 0x0008) ? (($perms & 0x0400) ? 's' : 'x' ) : (($perms & 0x0400) ? 'S' : '-'));

			// World
			$info .= (($perms & 0x0004) ? 'r' : '-');
			$info .= (($perms & 0x0002) ? 'w' : '-');
			$info .= (($perms & 0x0001) ? (($perms & 0x0200) ? 't' : 'x' ) : (($perms & 0x0200) ? 'T' : '-'));

			return $info;

		}

		/**
		* mkIcon(file_name, [icon_size])
		* @returns: HTML formatted correspondent icon for file_name
		*/
		function mkIcon($file, $size = 16) {
			return '<img src="'.files::fetchIcon($file, $size).'" width="'.$size.'" height="'.$size.'" alt="'.basename($file).'" />';
		}

		function fetchIcon($file, $size) {
			$icon = guessFileType($file);
			if (is_dir($file)) {
				return fetchIcon("files/folder.png", $size);
			} else {
				// icon exists?
				$icondir = GEKKO_SOURCE_DIR."media/icons/"._l("C_SITE.ICONTHEME")."/{$size}/files/";
				if (!file_exists($icondir.$icon.".png")) {
					if (!file_exists(GEKKO_SOURCE_DIR."media/icons/default/{$size}/files/{$icon}.png")) {
						$icon = "unknown";
					}
				}
				return fetchIcon("files/$icon.png", $size);
			}
		}

		/**
		* getType(absolute_file_path)
		* @returns: human readable file format
		*
		*/
		function getType($file) {
			// php >= 4.3.0
			if (function_exists("mime_content_type") && is_readable(ini_get("mime_magic.magicfile")))
				return mime_content_type($file);
			return file_extension($file);
		}
	}
?>